---
title: my_site
keywords: my_site
desc: my_site, generated by teedoc
---




<div id="home_page">
    <div>
        <h1><span>my_site</span></h1>
        <h3>congratulations! web comes out~</h3>
    </div>
    <div id="big_btn_wrapper">
        <div class="big_btn">
            <a href="/get_started/zh/">Get started</a>
        </div>
    </div>
</div>
